const babel = require('rollup-plugin-babel')
const nodeResolve = require('rollup-plugin-node-resolve')
const commonjs = require('rollup-plugin-commonjs')
const serve = require('rollup-plugin-serve')
const replace = require('rollup-plugin-replace')
const eslint = require('rollup-plugin-eslint')
const paths = require('./path')

module.exports = {
  entry: paths.appEntry,
  dest: 'dist',
  onwarn: function(warning) {
    // Skip certain warnings

    // should intercept ... but doesn't in some rollup versions
    if ( warning.code === 'THIS_IS_UNDEFINED' ) { return; }

    // console.warn everything else
    console.warn( warning.message );
  },
  plugins: [
    eslint({
      configFile: paths.ownEslintConfig,
      useEslintrc: false,
      include: ['src/**'],
      exclude: ['node_modules/**', 'dist/**']
    }),
    nodeResolve({
      module: false,
      main: true,
      preferBuiltins: true
    }),
    babel({
      exclude: 'node_modules/**'
    }),
    commonjs({
      include: /node_modules/
    }),
    replace({
      'process.env.NODE_ENV': JSON.stringify( 'devlopment' ),
      'process.env.BUILD_VERSION': JSON.stringify(process.env.BUILD_VERSION)
    }),
    serve({
      contentBase: paths.appZip,
      host: 'localhost',
      port: 3000
    })
  ]
}