const babel = require('rollup-plugin-babel')
const nodeResolve = require('rollup-plugin-node-resolve')
const commonjs = require('rollup-plugin-commonjs')
const replace = require('rollup-plugin-replace')
const paths = require('./path')
const eslint = require('rollup-plugin-eslint')

const date = new Date()
const dateString = `${date.getFullYear()}${date.getMonth()+1}${date.getDate()}${date.getHours()}${date.getMinutes()}${date.getSeconds()}`

module.exports = {
  entry: paths.appEntry,
  dest: 'dist',
  onwarn: function(warning) {
    // Skip certain warnings

    // should intercept ... but doesn't in some rollup versions
    if ( warning.code === 'THIS_IS_UNDEFINED' ) { return; }

    // console.warn everything else
    console.warn( warning.message );
  },
  plugins: [
    eslint({
      configFile: paths.ownEslintConfig,
      useEslintrc: false,
      include: ['src/**'],
      exclude: ['node_modules/**', 'dist/**']
    }),
    babel({
      exclude: 'node_modules/**'
    }),
    nodeResolve({
      module: false,
      main: true
    }),
    commonjs({
      include: 'node_modules/**'
    }),
    replace({
      'process.env.NODE_ENV': JSON.stringify( 'production' ),
      'process.env.BUILD_VERSION': JSON.stringify(process.env.BUILD_VERSION)
    })
  ]
}