const qiniu = require('qiniu')
const crypto = require('crypto')

const apiRoot = process.env.SERVER || 'https://meshtech.co'

module.exports = function deploy(filepath, bucket, key, appConfig, fingerprint) {
  const config = new qiniu.conf.Config()
  config.zone = qiniu.zone.Zone_z2
  config.RPC_TIMEOUT = 60000 // 3 min.
  const uploader = new qiniu.form_up.FormUploader(config)
  const putExtra = new qiniu.form_up.PutExtra(config) 
  return upload(uploader, putExtra, {
    filepath,
    bucket,
    key
  }).then(url => {
    return update(appConfig, url, fingerprint)
  })
}

async function upload (uploader, putExtra, opt) {
  const { filepath, bucket, key } = opt
  const { uploadToken, downloadUrl }  = await getQiniuUploadToken(bucket, key)
  return new Promise((resolve, reject) => {
    putExtra.fname = key
    putExtra.params = {
      'x:name': key
    }
    uploader.putFile(uploadToken, key, filepath, putExtra, function (respErr,
      respBody, respInfo) {
      if (respErr) {
        console.log(respErr.name)
        reject(respErr)
      } else if (respInfo.statusCode === 200) {
        resolve(downloadUrl)
      } else {
        console.log(respInfo.statusCode)
        console.log(respBody)
        reject(respBody)
      }
    })
  })
}

function update(appConfig, url, fingerprint) {
  const data = {
    packageName: appConfig.name,
    downloadURL: url,
    fingerprint: fingerprint,
    meshEngineVersion: appConfig.engineVersion
  }
  const signature = 'sha1=' + crypto.createHmac('sha1', appConfig.privateKey).update(JSON.stringify(data)).digest().toString('base64') 
  const server = apiRoot + '/api/packages/update'
  return fetch(server, {
    method: 'POST',
    headers: {
      'X-Developer-Access-Key': appConfig.accessKey,
      'X-Mesh-Signature': signature,
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(data)
  }).then(res => {
    if (res.status >= 400) {
      throw new Error(`mesh server return status code ${res.status}`)
    }
    return res.json()
  }).then(res => {
    if (res.code === 1) {
      return res.message
    } else {
      throw new Error(`mesh server throw error ${res.message} when updating package`)
    }
  })
}

function getQiniuUploadToken(bucket, key) {
  let data = JSON.stringify({
    bucket,
    key,
    applyTime: Date.now()
  })
  data = new Buffer(data).toString('base64')
  const param = data.replace(/\+/g, "-").replace(/\//g, "_") 
  let salt = 'iF0DcUu1xNj8IjTBIw02scEaZjCW1n0oYuRpWk9G'
  let sign = crypto.createHmac('sha1', salt).update(param).digest().toString('base64')
  const url = apiRoot + '/api/v2/cdn/uploadToken'
  return fetch(url, {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify({
      sign: sign,
      param: param
    })
  }).then(res => {
    if (res.status >= 400) {
      throw new Error(`mesh server return status code ${res.status} when get upload token`)
    }
    return res.json()
  }).then(res => {
    if (res.code === 1) {
      return res.data
    } else {
      throw new Error(`mesh server throw error ${res.message} when get upload token`)
    }
  })
}